Module: NRSER::Collection
- Defined in:
- lib/nrser/collection.rb
Overview
include this module in any custom classes to have them treated as collections instead of individual objects by the methods in this file
Constant Summary collapse
- STDLIB =
[Array
] stdlib classes that are considered collections. [ Array, Hash, Set, OpenStruct, ]