Method: NRSER::Types::ArrayType#items_from_strings
- Defined in:
- lib/nrser/types/arrays.rb
#items_from_strings(items) ⇒ Array
Called on an array of string items that have been split from a single string by Type#from_s to convert each individual item before Type#check is called on the value.
NRSER::Types::ArrayType implementation is a no-op that just returns items - this method is in place for subclasses to override.
81 82 83 |
# File 'lib/nrser/types/arrays.rb', line 81 def items_from_strings items items end |