Class: String
Overview
Extension methods for String
Unicode Stylization collapse
-
#u_bold ⇒ Object
Calls NRSER.u_bold on
self. -
#u_bold_italic ⇒ Object
Calls NRSER.u_bold_italic on
self. -
#u_italic ⇒ Object
Calls NRSER.u_italic on
self. -
#u_mono ⇒ Object
Calls NRSER.u_mono on
self.
Instance Method Summary collapse
- #dedent ⇒ Object
-
#ellipsis(*args) ⇒ Object
Calls NRSER.ellipsis on
self. - #indent(*args) ⇒ Object
-
#start_with?(*prefixes) ⇒ Boolean
Augment #start_with? to accept Regexp prefixes.
-
#stdlib_start_with? ⇒ Object
Alias the stdlib #start_with? 'cause we'll need to use it when redefining the method below.
- #to_const ⇒ Object
- #to_const! ⇒ Object
-
#to_pn ⇒ Pathname
Convert self into a Pathname.
- #unblock ⇒ Object
- #whitespace? ⇒ Boolean
-
#words(*args, &block) ⇒ Object
Calls NRSER.words on
self.
Instance Method Details
#dedent ⇒ Object
14 15 16 |
# File 'lib/nrser/core_ext/string.rb', line 14 def dedent NRSER.dedent self end |
#ellipsis(*args) ⇒ Object
Calls NRSER.ellipsis on self.
48 49 50 |
# File 'lib/nrser/core_ext/string.rb', line 48 def ellipsis *args NRSER.ellipsis self, *args end |
#indent(*args) ⇒ Object
19 20 21 |
# File 'lib/nrser/core_ext/string.rb', line 19 def indent *args NRSER.indent self, *args end |
#start_with?(*prefixes) ⇒ Boolean
Augment #start_with? to accept Regexp prefixes.
I guess I always just felt like this should work... so now it does (kinda, at least).
Everything should work the exact same for String prefixes.
Use Regexp ones at your own pleasure and peril.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/nrser/core_ext/string.rb', line 89 def start_with? *prefixes unless prefixes.any? { |x| Regexp === x } return stdlib_start_with? *prefixes end prefixes.any? { |prefix| case prefix when Regexp unless prefix.source.start_with? '\A', '^' prefix = Regexp.new( "\\A#{ prefix.source }", prefix. ) end prefix =~ self else stdlib_start_with? prefix end } end |
#stdlib_start_with? ⇒ Object
Alias the stdlib #start_with? 'cause we'll need to use it when redefining the method below.
62 |
# File 'lib/nrser/core_ext/string.rb', line 62 alias_method :stdlib_start_with?, :start_with? |
#to_const ⇒ Object
24 25 26 |
# File 'lib/nrser/core_ext/string.rb', line 24 def to_const safe_constantize end |
#to_const! ⇒ Object
29 30 31 |
# File 'lib/nrser/core_ext/string.rb', line 29 def to_const! constantize end |
#to_pn ⇒ Pathname
Returns Convert self into a Pathname.
37 38 39 |
# File 'lib/nrser/core_ext/string.rb', line 37 def to_pn Pathname.new self end |
#u_bold ⇒ Object
Calls NRSER.u_bold on self
119 120 121 |
# File 'lib/nrser/core_ext/string.rb', line 119 def u_bold NRSER.u_bold self end |
#u_bold_italic ⇒ Object
Calls NRSER.u_bold_italic on self
125 126 127 |
# File 'lib/nrser/core_ext/string.rb', line 125 def u_bold_italic NRSER.u_bold_italic self end |
#u_italic ⇒ Object
Calls NRSER.u_italic on self
113 114 115 |
# File 'lib/nrser/core_ext/string.rb', line 113 def u_italic NRSER.u_italic self end |
#u_mono ⇒ Object
Calls NRSER.u_mono on self
131 132 133 |
# File 'lib/nrser/core_ext/string.rb', line 131 def u_mono NRSER.u_mono self end |
#unblock ⇒ Object
9 10 11 |
# File 'lib/nrser/core_ext/string.rb', line 9 def unblock NRSER.unblock self end |
#whitespace? ⇒ Boolean
42 43 44 |
# File 'lib/nrser/core_ext/string.rb', line 42 def whitespace? NRSER.whitespace? self end |
#words(*args, &block) ⇒ Object
Calls NRSER.words on self
54 55 56 |
# File 'lib/nrser/core_ext/string.rb', line 54 def words *args, &block NRSER::words self, *args, &block end |